Re: [patch] confirm before sending to trash



On 03/16/2011 03:54 PM, Rui Tiago Cação Matos wrote:
> On 16 March 2011 15:21, Giorgio F. Gilestro <giorgio gilestro tk> wrote:
>> change Delete to Ctrl-Delete (like MacOSX).
> 
> Actually this one sounds good regardless of the undo work. While at
> it, add the keyboard accelerator to the Edit > Move to Trash entry
> too, which should actually be there already.
> 
> Rui

Alright, let's see if we can agree on this one. I am attaching the patch
agains git master.


--
http://gilest.ro
diff --git a/src/nautilus-view.c b/src/nautilus-view.c
index 18d35c9..5aafb70 100644
--- a/src/nautilus-view.c
+++ b/src/nautilus-view.c
@@ -7099,7 +7099,7 @@ static const GtkActionEntry directory_view_entries[] = {
   /* label, accelerator */       "RenameSelectAll", "<shift>F2",
   /* tooltip */                  NULL,
 				 G_CALLBACK (action_rename_select_all_callback) },
   /* name, stock id */         { "Trash", NULL,
   /* label, accelerator */       N_("Mo_ve to Trash"), NULL,
   /* tooltip */                  N_("Move each selected item to the Trash"),
 				 G_CALLBACK (action_trash_callback) },
@@ -9824,9 +9824,9 @@ nautilus_view_class_init (NautilusViewClass *klass)
 	g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
 
 	binding_set = gtk_binding_set_by_class (klass);
-	gtk_binding_entry_add_signal (binding_set, GDK_KEY_Delete, 0,
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_Delete, GDK_CONTROL_MASK,
 				      "trash", 0);
-	gtk_binding_entry_add_signal (binding_set, GDK_KEY_KP_Delete, 0,
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_KP_Delete, GDK_CONTROL_MASK,
 				      "trash", 0);
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_KP_Delete, GDK_SHIFT_MASK,
 				      "delete", 0);
@@ -7099,7 +7099,7 @@ static const GtkActionEntry directory_view_entries[] = {
   /* tooltip */                  NULL,
 				 G_CALLBACK (action_rename_select_all_callback) },
-  /* name, stock id */         { "Trash", NULL,
+  /* name, stock id */         { "Trash", "<control>Delete",
   /* label, accelerator */       N_("Mo_ve to Trash"), NULL,
   /* tooltip */                  N_("Move each selected item to the Trash"),


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]